PyBEL Tools Documentation
=========================

`PyBEL Tools <http://pybel-tools.readthedocs.io/>`_ is a suite of tools built on top of
`PyBEL <http://pybel.readthedocs.io>`_ to facilitate data management, integration, and analysis. For further examples,
see the `PyBEL Notebooks <https://github.com/pybel/pybel-notebooks>`_ repository.

Links
-----
- Documented on `Read the Docs <http://pybel-tools.readthedocs.io/>`_
- Versioned on `GitHub <https://github.com/pybel/pybel-tools>`_
- Tested on `Travis CI <https://travis-ci.org/pybel/pybel-tools>`_
- Distributed by `PyPI <https://pypi.python.org/pypi/pybel-tools>`_
- Chat on `Gitter <https://gitter.im/pybel/Lobby>`_

.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: springboard

   installation
   cookbook

.. toctree::
   :maxdepth: 2
   :caption: Graph Utilities
   :name: graphutils

   summary
   filters
   comparison
   selection
   integration
   mutation
   visualization

.. toctree::
   :maxdepth: 2
   :caption: Analysis
   :name: analysis

   stability

.. toctree::
   :caption: Pipelines
   :name: pipelines

   orthology
   expansion
   generation
   cmpa
   pipeline

.. toctree::
   :caption: Services
   :name: services

   databaseservice

.. toctree::
   :caption: Other Utilities
   :name: utilities

   ioutils
   documentutils
   resourceutils
   utilities
   lexer


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
